@@ -11,10 +11,10 @@ from typing import Any, Optional
 from requests import Response, Session
 from requests.exceptions import RequestException
 
-from metabase_tools.endpoint.cards_endpoint import Cards
-from metabase_tools.endpoint.collection_endpoint import Collections
-from metabase_tools.endpoint.database_endpoint import Databases
-from metabase_tools.endpoint.user_endpoint import Users
+from metabase_tools.endpoints.cards_endpoint import Cards
+from metabase_tools.endpoints.collections_endpoint import Collections
+from metabase_tools.endpoints.databases_endpoint import Databases
+from metabase_tools.endpoints.users_endpoint import Users
 from metabase_tools.exceptions import (
     AuthenticationFailure,
     InvalidDataReceived,
@@ -22,6 +22,8 @@ from metabase_tools.exceptions import (
 )
 from metabase_tools.tools import MetabaseTools
 
+logger = logging.getLogger(__name__)
+
 
 class MetabaseApi:
     """Metabase API adapter"""
@@ -39,7 +41,6 @@ class MetabaseApi:
         cache_token: bool = False,
         token_path: Optional[Path | str] = None,
     ):
-        self._logger = logging.getLogger(__name__)
         if not credentials and not token_path:
             raise AuthenticationFailure("No authentication method provided")
         credentials = credentials or {}
@@ -56,7 +57,7 @@ class MetabaseApi:
 
         if cache_token:
             save_path = Path(token_path or "metabase.token")
-            self.save_token(save_path=save_path)
+            self._save_token(save_path=save_path)
 
         self.cards = Cards(self)
         self.collections = Collections(self)
@@ -90,7 +91,7 @@ class MetabaseApi:
             authed = self._auth_with_login(credentials=credentials)
         # Raise error if still not authenticated
         if not authed:
-            self._logger.error("Failed to authenticate")
+            logger.error("Failed to authenticate")
             raise AuthenticationFailure(
                 "Failed to authenticate with credentials provided"
             )
@@ -104,16 +105,16 @@ class MetabaseApi:
 
     def _delete_cached_token(self, token_path: Path) -> None:
         if token_path.exists():
-            self._logger.warning("Deleting token file")
+            logger.warning("Deleting token file")
             token_path.unlink()
 
     def _auth_with_cached_token(self, token_path: Path) -> bool:
         with open(token_path, "r", encoding="utf-8") as file:
             token = file.read()
-        self._logger.debug("Attempting authentication with token file")
+        logger.info("Attempting authentication with token file")
         self._add_token_to_header(token=token)
         authed = self.test_for_auth()
-        self._logger.debug(
+        logger.info(
             "Authenticated with token file"
             if authed
             else "Failed to authenticate with token file"
@@ -121,10 +122,10 @@ class MetabaseApi:
         return authed
 
     def _auth_with_passed_token(self, credentials: dict[str, str]) -> bool:
-        self._logger.debug("Attempting authentication with token passed")
+        logger.info("Attempting authentication with token passed")
         self._add_token_to_header(token=credentials["token"])
         authed = self.test_for_auth()
-        self._logger.debug(
+        logger.info(
             "Authenticated with token passed"
             if authed
             else "Failed to authenticate with token passed"
@@ -138,20 +139,20 @@ class MetabaseApi:
             credentials (dict): Username and password
         """
         try:
-            self._logger.debug("Attempting authentication with username and password")
+            logger.info("Attempting authentication with username and password")
             response = self._session.post(
                 f"{self.metabase_url}/session", json=credentials
             )
             self._add_token_to_header(token=response.json()["id"])
             authed = self.test_for_auth()
-            self._logger.debug(
+            logger.info(
                 "Authenticated with login"
                 if authed
                 else "Failed to authenticate with login"
             )
             return authed
         except KeyError as error_raised:
-            self._logger.warning(
+            logger.warning(
                 "Exception encountered during attempt to authenticate with login \
                     passed: %s",
                 error_raised,
@@ -163,7 +164,7 @@ class MetabaseApi:
             the current user
 
         Returns:
-            bool: Successful authentication
+            bool: Authentication success status
         """
         return (
             200
@@ -171,7 +172,7 @@ class MetabaseApi:
             <= 299
         )
 
-    def save_token(self, save_path: Path | str) -> None:
+    def _save_token(self, save_path: Path | str) -> None:
         """Writes active token to the specified file
 
         Args:
@@ -204,12 +205,12 @@ class MetabaseApi:
         """
         log_line_pre = f"{method=}, {url=}, {params=}"
         try:
-            self._logger.debug(log_line_pre)
+            logger.info(log_line_pre)
             return self._session.request(
                 method=method, url=url, params=params, json=json
             )
         except RequestException as error_raised:
-            self._logger.error(str(error_raised))
+            logger.error(str(error_raised))
             raise RequestFailure("Request failed") from error_raised
 
     def generic_request(
@@ -249,7 +250,7 @@ class MetabaseApi:
 
         is_success = 299 >= response.status_code >= 200
         if is_success:
-            self._logger.debug(
+            logger.info(
                 log_line_post, is_success, response.status_code, response.reason
             )
             try:
@@ -257,15 +258,14 @@ class MetabaseApi:
                 if isinstance(return_, (list, dict)):
                     return return_
             except JSONDecodeError as error_raised:
+                logger.error(log_line_post, False, response.status_code, response.text)
                 raise InvalidDataReceived from error_raised
         elif response.status_code == 401:
-            self._logger.error(
-                log_line_post, False, response.status_code, response.text
-            )
+            logger.error(log_line_post, False, response.status_code, response.text)
             raise AuthenticationFailure(f"{response.status_code} - {response.reason}")
 
-        error_line = f"{response.status_code} - {response.reason}"
-        self._logger.error(log_line_post)
+        error_line = f"{response.status_code} - {response.reason} - {response.text}"
+        logger.error(log_line_post, False, response.status_code, response.text)
         raise RequestFailure(error_line)
 
     def get(
